Class: Google::Apis::CurationpartnersV1::CurationPartnersService

Inherits:
Google::Apis::Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/curationpartners_v1/service.rb

Overview

Curation Partners API

Curation partners API is an externally available HTTP API for curators to programmatically manage their data segments and curated packages used by ad agencies.

Examples:

require 'google/apis/curationpartners_v1'

Curationpartners = Google::Apis::CurationpartnersV1 # Alias the module
service = Curationpartners::CurationPartnersService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://curationpartners.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeCurationPartnersService

Returns a new instance of CurationPartnersService.



49
50
51
52
53
54
# File 'lib/google/apis/curationpartners_v1/service.rb', line 49

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-curationpartners_v1',
        client_version: Google::Apis::CurationpartnersV1::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



42
43
44
# File 'lib/google/apis/curationpartners_v1/service.rb', line 42

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



47
48
49
# File 'lib/google/apis/curationpartners_v1/service.rb', line 47

def quota_user
  @quota_user
end

Instance Method Details

#activate_curated_package(name, activate_curated_package_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage

Activates an existing curated package.

Parameters:

  • name (String)

    Required. The name of the curated package to activate. Format: curators/ accountId/curatedPackages/curatedPackageId``

  • activate_curated_package_request_object (Google::Apis::CurationpartnersV1::ActivateCuratedPackageRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



78
79
80
81
82
83
84
85
86
87
88
# File 'lib/google/apis/curationpartners_v1/service.rb', line 78

def activate_curated_package(name, activate_curated_package_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+name}:activate', options)
  command.request_representation = Google::Apis::CurationpartnersV1::ActivateCuratedPackageRequest::Representation
  command.request_object = activate_curated_package_request_object
  command.response_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation
  command.response_class = Google::Apis::CurationpartnersV1::CuratedPackage
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#activate_data_segment(name, activate_data_segment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment

Activates a data segment.

Parameters:

  • name (String)

    Required. Name of data segment to activate. Format: curators/accountId/ dataSegments/curatorDataSegmentId``

  • activate_data_segment_request_object (Google::Apis::CurationpartnersV1::ActivateDataSegmentRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



303
304
305
306
307
308
309
310
311
312
313
# File 'lib/google/apis/curationpartners_v1/service.rb', line 303

def activate_data_segment(name, activate_data_segment_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+name}:activate', options)
  command.request_representation = Google::Apis::CurationpartnersV1::ActivateDataSegmentRequest::Representation
  command.request_object = activate_data_segment_request_object
  command.response_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation
  command.response_class = Google::Apis::CurationpartnersV1::DataSegment
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_curator_curated_package(parent, curated_package_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage

Creates a new curated package.

Parameters:

  • parent (String)

    Required. The parent curator account where this curated package will be created. Format: curators/accountId``

  • curated_package_object (Google::Apis::CurationpartnersV1::CuratedPackage) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



112
113
114
115
116
117
118
119
120
121
122
# File 'lib/google/apis/curationpartners_v1/service.rb', line 112

def create_curator_curated_package(parent, curated_package_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+parent}/curatedPackages', options)
  command.request_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation
  command.request_object = curated_package_object
  command.response_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation
  command.response_class = Google::Apis::CurationpartnersV1::CuratedPackage
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_curator_data_segment(parent, data_segment_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment

Creates a data segment owned by the listed curator. The data segment will be created in the ACTIVE state, meaning it will be immediately available for buyers to use in preferred deals, private auction deals, and auction packages.

Parameters:

  • parent (String)

    Required. The parent resource where this data segment will be created. Format: curators/accountId``

  • data_segment_object (Google::Apis::CurationpartnersV1::DataSegment) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



339
340
341
342
343
344
345
346
347
348
349
# File 'lib/google/apis/curationpartners_v1/service.rb', line 339

def create_curator_data_segment(parent, data_segment_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+parent}/dataSegments', options)
  command.request_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation
  command.request_object = data_segment_object
  command.response_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation
  command.response_class = Google::Apis::CurationpartnersV1::DataSegment
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_curator_report(parent, report_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Report

Creates a Report object.

Parameters:

  • parent (String)

    Required. The parent resource where this Report will be created. Format: curators/account_id``

  • report_object (Google::Apis::CurationpartnersV1::Report) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



523
524
525
526
527
528
529
530
531
532
533
# File 'lib/google/apis/curationpartners_v1/service.rb', line 523

def create_curator_report(parent, report_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+parent}/reports', options)
  command.request_representation = Google::Apis::CurationpartnersV1::Report::Representation
  command.request_object = report_object
  command.response_representation = Google::Apis::CurationpartnersV1::Report::Representation
  command.response_class = Google::Apis::CurationpartnersV1::Report
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#deactivate_curated_package(name, deactivate_curated_package_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage

Deactivates an existing curated package.

Parameters:

  • name (String)

    Required. The name of the curated package to deactivate. Format: curators/ accountId/curatedPackages/curatedPackageId``

  • deactivate_curated_package_request_object (Google::Apis::CurationpartnersV1::DeactivateCuratedPackageRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



146
147
148
149
150
151
152
153
154
155
156
# File 'lib/google/apis/curationpartners_v1/service.rb', line 146

def deactivate_curated_package(name, deactivate_curated_package_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+name}:deactivate', options)
  command.request_representation = Google::Apis::CurationpartnersV1::DeactivateCuratedPackageRequest::Representation
  command.request_object = deactivate_curated_package_request_object
  command.response_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation
  command.response_class = Google::Apis::CurationpartnersV1::CuratedPackage
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#deactivate_data_segment(name, deactivate_data_segment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment

Deactivates a data segment.

Parameters:

  • name (String)

    Required. Name of data segment to deactivate. Format: curators/accountId/ dataSegments/curatorDataSegmentId``

  • deactivate_data_segment_request_object (Google::Apis::CurationpartnersV1::DeactivateDataSegmentRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



373
374
375
376
377
378
379
380
381
382
383
# File 'lib/google/apis/curationpartners_v1/service.rb', line 373

def deactivate_data_segment(name, deactivate_data_segment_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+name}:deactivate', options)
  command.request_representation = Google::Apis::CurationpartnersV1::DeactivateDataSegmentRequest::Representation
  command.request_object = deactivate_data_segment_request_object
  command.response_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation
  command.response_class = Google::Apis::CurationpartnersV1::DataSegment
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_curator_report(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Empty

Deletes a Report object.

Parameters:

  • name (String)

    Required. Resource name of the report to delete. Format: curators/account_id /reports/report_id``

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



556
557
558
559
560
561
562
563
564
# File 'lib/google/apis/curationpartners_v1/service.rb', line 556

def delete_curator_report(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1/{+name}', options)
  command.response_representation = Google::Apis::CurationpartnersV1::Empty::Representation
  command.response_class = Google::Apis::CurationpartnersV1::Empty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#fetch_curator_report_result_rows(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::FetchReportResultRowsResponse

Returns the result rows from a completed report. The caller must have previously called RunReport and waited for that operation to complete. The rows will be returned according to the order specified by the sorts member of the report definition.

Parameters:

  • name (String)

    The report result being fetched. Format: curators/account_id/reports/ report_id/results/report_result_id``

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of rows to return. The service may return fewer than this value. If unspecified, at most 1,000 rows will be returned. The maximum value is 10,000; values greater than 10,000 will be reduced to 10,000.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous FetchReportResultRows call. Provide this to retrieve the second and subsequent batches of rows.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



787
788
789
790
791
792
793
794
795
796
797
# File 'lib/google/apis/curationpartners_v1/service.rb', line 787

def fetch_curator_report_result_rows(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}:fetchRows', options)
  command.response_representation = Google::Apis::CurationpartnersV1::FetchReportResultRowsResponse::Representation
  command.response_class = Google::Apis::CurationpartnersV1::FetchReportResultRowsResponse
  command.params['name'] = name unless name.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_curator_curated_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage

Gets a curated package given its resource name.

Parameters:

  • name (String)

    Required. The name of the curated package to retrieve. Format: curators/ accountId/curatedPackages/curatedPackageId``

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



179
180
181
182
183
184
185
186
187
# File 'lib/google/apis/curationpartners_v1/service.rb', line 179

def get_curator_curated_package(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation
  command.response_class = Google::Apis::CurationpartnersV1::CuratedPackage
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_curator_data_segment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment

Gets a data segment given its name.

Parameters:

  • name (String)

    Required. Name of data segment to get. Format: curators/accountId/ dataSegments/curatorDataSegmentId``

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



406
407
408
409
410
411
412
413
414
# File 'lib/google/apis/curationpartners_v1/service.rb', line 406

def get_curator_data_segment(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation
  command.response_class = Google::Apis::CurationpartnersV1::DataSegment
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_curator_report(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Report

Retrieves a Report object.

Parameters:

  • name (String)

    Required. The resource name of the report. Format: curators/account_id/ reports/report_id``

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



587
588
589
590
591
592
593
594
595
# File 'lib/google/apis/curationpartners_v1/service.rb', line 587

def get_curator_report(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::CurationpartnersV1::Report::Representation
  command.response_class = Google::Apis::CurationpartnersV1::Report
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_curator_report_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Operation

Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.

Parameters:

  • name (String)

    The name of the operation resource.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



746
747
748
749
750
751
752
753
754
# File 'lib/google/apis/curationpartners_v1/service.rb', line 746

def get_curator_report_operation(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::CurationpartnersV1::Operation::Representation
  command.response_class = Google::Apis::CurationpartnersV1::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_curator_curated_packages(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::ListCuratedPackagesResponse

Lists curated packages owned by the specified curator.

Parameters:

  • parent (String)

    Required. The parent curator account which owns this collection of curated packages. Format: curators/accountId``

  • filter (String) (defaults to: nil)

    Optional. Optional query string using the Cloud API list filtering syntax. Supported columns for filtering are: * displayName * createTime * updateTime * state * feeCpm.currencyCode * feeCpm.units * feeCpm.nanos * floorPriceCpm.currencyCode * floorPriceCpm.units

    • floorPriceCpm.nanos
  • page_size (Fixnum) (defaults to: nil)

    Optional. Requested page size. The server may return fewer results than requested. Max allowed page size is 500. If unspecified, the server will default to 500.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListCuratedPackages call. Provide this to retrieve the subsequent page.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/google/apis/curationpartners_v1/service.rb', line 223

def list_curator_curated_packages(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/curatedPackages', options)
  command.response_representation = Google::Apis::CurationpartnersV1::ListCuratedPackagesResponse::Representation
  command.response_class = Google::Apis::CurationpartnersV1::ListCuratedPackagesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_curator_data_segments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::ListDataSegmentsResponse

List the data segments owned by a curator.

Parameters:

  • parent (String)

    Required. Name of the parent curator that can access the data segment. Format: curators/accountId``

  • page_size (Fixnum) (defaults to: nil)

    Optional. Requested page size. The server may return fewer results than requested. Max allowed page size is 500. If unspecified, the server will default to 500.

  • page_token (String) (defaults to: nil)

    Optional. The page token as returned. ListDataSegmentsResponse.nextPageToken

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



443
444
445
446
447
448
449
450
451
452
453
# File 'lib/google/apis/curationpartners_v1/service.rb', line 443

def list_curator_data_segments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/dataSegments', options)
  command.response_representation = Google::Apis::CurationpartnersV1::ListDataSegmentsResponse::Representation
  command.response_class = Google::Apis::CurationpartnersV1::ListDataSegmentsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_curator_reports(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, skip: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::ListReportsResponse

Lists Report objects.

Parameters:

  • parent (String)

    Required. The parent, which owns this collection of reports. Format: curators/ account_id``

  • filter (String) (defaults to: nil)

    Optional. Expression to filter the response. See syntax details at https:// developers.google.com/ad-manager/api/beta/filters

  • order_by (String) (defaults to: nil)

    Optional. Expression to specify sorting order. See syntax details at https:// developers.google.com/ad-manager/api/beta/filters#order

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of Reports to return. The service may return fewer than this value. If unspecified, at most 50 Reports will be returned. The maximum value is 1000; values greater than 1000 will be coerced to 1000.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListReports call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListReports must match the call that provided the page token.

  • skip (Fixnum) (defaults to: nil)

    Optional. Number of individual resources to skip while paginating.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



634
635
636
637
638
639
640
641
642
643
644
645
646
647
# File 'lib/google/apis/curationpartners_v1/service.rb', line 634

def list_curator_reports(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, skip: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/reports', options)
  command.response_representation = Google::Apis::CurationpartnersV1::ListReportsResponse::Representation
  command.response_class = Google::Apis::CurationpartnersV1::ListReportsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['orderBy'] = order_by unless order_by.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['skip'] = skip unless skip.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_media_planners(filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::ListMediaPlannersResponse

Lists all media planner accounts that the caller has access to. For curators, this will return all media planners that have accepted curator terms. For other accounts, attempting to list media planners will return an error.

Parameters:

  • filter (String) (defaults to: nil)

    Optional query string using the Cloud API list filtering syntax. Supported columns for filtering are: * name

    • displayName * ancestorNames
  • page_size (Fixnum) (defaults to: nil)

    The maximum number of media planners to return. If unspecified, at most 100 media planners will be returned. The maximum value is 500; values above 500 will be coerced to 500.

  • page_token (String) (defaults to: nil)

    Optional. A token identifying a page of results the server should return.This value is received from a previous ListMediaPlanners call in ListMediaPlannersResponse.nextPageToken.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



831
832
833
834
835
836
837
838
839
840
841
# File 'lib/google/apis/curationpartners_v1/service.rb', line 831

def list_media_planners(filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/mediaPlanners', options)
  command.response_representation = Google::Apis::CurationpartnersV1::ListMediaPlannersResponse::Representation
  command.response_class = Google::Apis::CurationpartnersV1::ListMediaPlannersResponse
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_curator_curated_package(name, curated_package_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage

Updates an existing curated package.

Parameters:

  • name (String)

    Identifier. The unique resource name for the curated package. Format: curators/accountId/curatedPackages/curatedPackageId``

  • curated_package_object (Google::Apis::CurationpartnersV1::CuratedPackage) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    Optional. List of fields to be updated. If empty or unspecified, the service will update all fields populated in the update request excluding the output only fields and primitive fields with default value. Note that explicit field mask is required in order to reset a primitive field back to its default value, for example, false for boolean fields, 0 for integer fields. A special field mask consisting of a single path "*" can be used to indicate full replacement ( the equivalent of PUT method), updatable fields unset or unspecified in the input will be cleared or set to default value. Output only fields will be ignored regardless of the value of updateMask.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/google/apis/curationpartners_v1/service.rb', line 268

def patch_curator_curated_package(name, curated_package_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1/{+name}', options)
  command.request_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation
  command.request_object = curated_package_object
  command.response_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation
  command.response_class = Google::Apis::CurationpartnersV1::CuratedPackage
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_curator_data_segment(name, data_segment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment

Updates a data segment.

Parameters:

  • name (String)

    Immutable. Identifier. The unique identifier for the data segment. Account ID corresponds to the account ID that created the segment. Format: curators/ curatorAccountId/dataSegments/curatorDataSegmentId``

  • data_segment_object (Google::Apis::CurationpartnersV1::DataSegment) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    Optional. List of fields to be updated. If empty or unspecified, the service will update all fields populated in the update request excluding the output only fields and primitive fields with default value. Note that explicit field mask is required in order to reset a primitive field back to its default value, for example, false for boolean fields, 0 for integer fields. A special field mask consisting of a single path "*" can be used to indicate full replacement( the equivalent of PUT method), updatable fields unset or unspecified in the input will be cleared or set to default value. Output only fields will be ignored regardless of the value of updateMask.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



488
489
490
491
492
493
494
495
496
497
498
499
# File 'lib/google/apis/curationpartners_v1/service.rb', line 488

def patch_curator_data_segment(name, data_segment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1/{+name}', options)
  command.request_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation
  command.request_object = data_segment_object
  command.response_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation
  command.response_class = Google::Apis::CurationpartnersV1::DataSegment
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_curator_report(name, report_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Report

Updates a Report object.

Parameters:

  • name (String)

    Identifier. The resource name of the report. Report resource name have the form: curators/account_id/reports/report_id``

  • report_object (Google::Apis::CurationpartnersV1::Report) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    Optional. The list of fields to update.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/google/apis/curationpartners_v1/service.rb', line 673

def patch_curator_report(name, report_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1/{+name}', options)
  command.request_representation = Google::Apis::CurationpartnersV1::Report::Representation
  command.request_object = report_object
  command.response_representation = Google::Apis::CurationpartnersV1::Report::Representation
  command.response_class = Google::Apis::CurationpartnersV1::Report
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#run_report(name, run_report_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Operation

Initiates the execution of an existing report asynchronously. Users can get the report by polling this operation using OperationsService.GetOperation. Poll every 5 seconds initially, with an exponential backoff. Once a report is complete, the operation will contain a RunReportResponse in its response field containing a report_result that can be passed to the FetchReportResultRows method to retrieve the report data.

Parameters:

  • name (String)

    Required. The report to run. Format: curators/account_id/reports/report_id

  • run_report_request_object (Google::Apis::CurationpartnersV1::RunReportRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



713
714
715
716
717
718
719
720
721
722
723
# File 'lib/google/apis/curationpartners_v1/service.rb', line 713

def run_report(name, run_report_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+name}:run', options)
  command.request_representation = Google::Apis::CurationpartnersV1::RunReportRequest::Representation
  command.request_object = run_report_request_object
  command.response_representation = Google::Apis::CurationpartnersV1::Operation::Representation
  command.response_class = Google::Apis::CurationpartnersV1::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end