Class: Google::Apis::CurationpartnersV1::CurationPartnersService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::CurationpartnersV1::CurationPartnersService
- Defined in:
- lib/google/apis/curationpartners_v1/service.rb
Overview
Curation Partners API
Curation partners API is an externally available HTTP API for curators to programmatically manage their data segments and curated packages used by ad agencies.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://curationpartners.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#activate_curated_package(name, activate_curated_package_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage
Activates an existing curated package.
-
#activate_data_segment(name, activate_data_segment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment
Activates a data segment.
-
#create_curator_curated_package(parent, curated_package_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage
Creates a new curated package.
-
#create_curator_data_segment(parent, data_segment_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment
Creates a data segment owned by the listed curator.
-
#create_curator_report(parent, report_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Report
Creates a
Reportobject. -
#deactivate_curated_package(name, deactivate_curated_package_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage
Deactivates an existing curated package.
-
#deactivate_data_segment(name, deactivate_data_segment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment
Deactivates a data segment.
-
#delete_curator_report(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Empty
Deletes a
Reportobject. -
#fetch_curator_report_result_rows(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::FetchReportResultRowsResponse
Returns the result rows from a completed report.
-
#get_curator_curated_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage
Gets a curated package given its resource name.
-
#get_curator_data_segment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment
Gets a data segment given its name.
-
#get_curator_report(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Report
Retrieves a
Reportobject. -
#get_curator_report_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ CurationPartnersService
constructor
A new instance of CurationPartnersService.
-
#list_curator_curated_packages(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::ListCuratedPackagesResponse
Lists curated packages owned by the specified curator.
-
#list_curator_data_segments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::ListDataSegmentsResponse
List the data segments owned by a curator.
-
#list_curator_reports(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, skip: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::ListReportsResponse
Lists
Reportobjects. -
#list_media_planners(filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::ListMediaPlannersResponse
Lists all media planner accounts that the caller has access to.
-
#patch_curator_curated_package(name, curated_package_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage
Updates an existing curated package.
-
#patch_curator_data_segment(name, data_segment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment
Updates a data segment.
-
#patch_curator_report(name, report_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Report
Updates a
Reportobject. -
#run_report(name, run_report_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Operation
Initiates the execution of an existing report asynchronously.
Constructor Details
#initialize ⇒ CurationPartnersService
Returns a new instance of CurationPartnersService.
49 50 51 52 53 54 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 49 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-curationpartners_v1', client_version: Google::Apis::CurationpartnersV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
42 43 44 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 42 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
47 48 49 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 47 def quota_user @quota_user end |
Instance Method Details
#activate_curated_package(name, activate_curated_package_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage
Activates an existing curated package.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 78 def activate_curated_package(name, activate_curated_package_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:activate', ) command.request_representation = Google::Apis::CurationpartnersV1::ActivateCuratedPackageRequest::Representation command.request_object = activate_curated_package_request_object command.response_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation command.response_class = Google::Apis::CurationpartnersV1::CuratedPackage command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#activate_data_segment(name, activate_data_segment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment
Activates a data segment.
303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 303 def activate_data_segment(name, activate_data_segment_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:activate', ) command.request_representation = Google::Apis::CurationpartnersV1::ActivateDataSegmentRequest::Representation command.request_object = activate_data_segment_request_object command.response_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation command.response_class = Google::Apis::CurationpartnersV1::DataSegment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_curator_curated_package(parent, curated_package_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage
Creates a new curated package.
112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 112 def create_curator_curated_package(parent, curated_package_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/curatedPackages', ) command.request_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation command.request_object = curated_package_object command.response_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation command.response_class = Google::Apis::CurationpartnersV1::CuratedPackage command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_curator_data_segment(parent, data_segment_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment
Creates a data segment owned by the listed curator. The data segment will be
created in the ACTIVE state, meaning it will be immediately available for
buyers to use in preferred deals, private auction deals, and auction packages.
339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 339 def create_curator_data_segment(parent, data_segment_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/dataSegments', ) command.request_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation command.request_object = data_segment_object command.response_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation command.response_class = Google::Apis::CurationpartnersV1::DataSegment command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_curator_report(parent, report_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Report
Creates a Report object.
523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 523 def create_curator_report(parent, report_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/reports', ) command.request_representation = Google::Apis::CurationpartnersV1::Report::Representation command.request_object = report_object command.response_representation = Google::Apis::CurationpartnersV1::Report::Representation command.response_class = Google::Apis::CurationpartnersV1::Report command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#deactivate_curated_package(name, deactivate_curated_package_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage
Deactivates an existing curated package.
146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 146 def deactivate_curated_package(name, deactivate_curated_package_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:deactivate', ) command.request_representation = Google::Apis::CurationpartnersV1::DeactivateCuratedPackageRequest::Representation command.request_object = deactivate_curated_package_request_object command.response_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation command.response_class = Google::Apis::CurationpartnersV1::CuratedPackage command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#deactivate_data_segment(name, deactivate_data_segment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment
Deactivates a data segment.
373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 373 def deactivate_data_segment(name, deactivate_data_segment_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:deactivate', ) command.request_representation = Google::Apis::CurationpartnersV1::DeactivateDataSegmentRequest::Representation command.request_object = deactivate_data_segment_request_object command.response_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation command.response_class = Google::Apis::CurationpartnersV1::DataSegment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_curator_report(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Empty
Deletes a Report object.
556 557 558 559 560 561 562 563 564 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 556 def delete_curator_report(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::CurationpartnersV1::Empty::Representation command.response_class = Google::Apis::CurationpartnersV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#fetch_curator_report_result_rows(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::FetchReportResultRowsResponse
Returns the result rows from a completed report. The caller must have
previously called RunReport and waited for that operation to complete. The
rows will be returned according to the order specified by the sorts member
of the report definition.
787 788 789 790 791 792 793 794 795 796 797 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 787 def fetch_curator_report_result_rows(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:fetchRows', ) command.response_representation = Google::Apis::CurationpartnersV1::FetchReportResultRowsResponse::Representation command.response_class = Google::Apis::CurationpartnersV1::FetchReportResultRowsResponse command.params['name'] = name unless name.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_curator_curated_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage
Gets a curated package given its resource name.
179 180 181 182 183 184 185 186 187 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 179 def get_curator_curated_package(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation command.response_class = Google::Apis::CurationpartnersV1::CuratedPackage command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_curator_data_segment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment
Gets a data segment given its name.
406 407 408 409 410 411 412 413 414 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 406 def get_curator_data_segment(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation command.response_class = Google::Apis::CurationpartnersV1::DataSegment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_curator_report(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Report
Retrieves a Report object.
587 588 589 590 591 592 593 594 595 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 587 def get_curator_report(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CurationpartnersV1::Report::Representation command.response_class = Google::Apis::CurationpartnersV1::Report command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_curator_report_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
746 747 748 749 750 751 752 753 754 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 746 def get_curator_report_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CurationpartnersV1::Operation::Representation command.response_class = Google::Apis::CurationpartnersV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_curator_curated_packages(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::ListCuratedPackagesResponse
Lists curated packages owned by the specified curator.
223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 223 def list_curator_curated_packages(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/curatedPackages', ) command.response_representation = Google::Apis::CurationpartnersV1::ListCuratedPackagesResponse::Representation command.response_class = Google::Apis::CurationpartnersV1::ListCuratedPackagesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_curator_data_segments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::ListDataSegmentsResponse
List the data segments owned by a curator.
443 444 445 446 447 448 449 450 451 452 453 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 443 def list_curator_data_segments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/dataSegments', ) command.response_representation = Google::Apis::CurationpartnersV1::ListDataSegmentsResponse::Representation command.response_class = Google::Apis::CurationpartnersV1::ListDataSegmentsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_curator_reports(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, skip: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::ListReportsResponse
Lists Report objects.
634 635 636 637 638 639 640 641 642 643 644 645 646 647 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 634 def list_curator_reports(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, skip: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/reports', ) command.response_representation = Google::Apis::CurationpartnersV1::ListReportsResponse::Representation command.response_class = Google::Apis::CurationpartnersV1::ListReportsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['skip'] = skip unless skip.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_media_planners(filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::ListMediaPlannersResponse
Lists all media planner accounts that the caller has access to. For curators, this will return all media planners that have accepted curator terms. For other accounts, attempting to list media planners will return an error.
831 832 833 834 835 836 837 838 839 840 841 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 831 def list_media_planners(filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/mediaPlanners', ) command.response_representation = Google::Apis::CurationpartnersV1::ListMediaPlannersResponse::Representation command.response_class = Google::Apis::CurationpartnersV1::ListMediaPlannersResponse command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_curator_curated_package(name, curated_package_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::CuratedPackage
Updates an existing curated package.
268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 268 def patch_curator_curated_package(name, curated_package_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation command.request_object = curated_package_object command.response_representation = Google::Apis::CurationpartnersV1::CuratedPackage::Representation command.response_class = Google::Apis::CurationpartnersV1::CuratedPackage command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_curator_data_segment(name, data_segment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::DataSegment
Updates a data segment.
488 489 490 491 492 493 494 495 496 497 498 499 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 488 def patch_curator_data_segment(name, data_segment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation command.request_object = data_segment_object command.response_representation = Google::Apis::CurationpartnersV1::DataSegment::Representation command.response_class = Google::Apis::CurationpartnersV1::DataSegment command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_curator_report(name, report_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Report
Updates a Report object.
673 674 675 676 677 678 679 680 681 682 683 684 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 673 def patch_curator_report(name, report_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::CurationpartnersV1::Report::Representation command.request_object = report_object command.response_representation = Google::Apis::CurationpartnersV1::Report::Representation command.response_class = Google::Apis::CurationpartnersV1::Report command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#run_report(name, run_report_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CurationpartnersV1::Operation
Initiates the execution of an existing report asynchronously. Users can get
the report by polling this operation using OperationsService.GetOperation.
Poll every 5 seconds initially, with an exponential backoff. Once a report is
complete, the operation will contain a RunReportResponse in its response
field containing a report_result that can be passed to the
FetchReportResultRows method to retrieve the report data.
713 714 715 716 717 718 719 720 721 722 723 |
# File 'lib/google/apis/curationpartners_v1/service.rb', line 713 def run_report(name, run_report_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:run', ) command.request_representation = Google::Apis::CurationpartnersV1::RunReportRequest::Representation command.request_object = run_report_request_object command.response_representation = Google::Apis::CurationpartnersV1::Operation::Representation command.response_class = Google::Apis::CurationpartnersV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |